@@ -1,6 +1,7 @@
 package archive
 
 import (
+	"io"
 	"os"
 	"testing"
 
@@ -15,15 +16,13 @@ func TestArchive(t *testing.T) {
 	require.NoError(t, empty.Close())
 	require.NoError(t, os.Mkdir(folder+"/folder-inside", 0o755))
 
-	for _, format := range []string{"tar.gz", "zip", "gz", "tar.xz", "tar", "willbeatargzanyway"} {
+	for _, format := range []string{"tar.gz", "zip", "gz", "tar.xz", "tar"} {
 		format := format
 		t.Run(format, func(t *testing.T) {
-			file, err := os.Create(folder + "/folder." + format)
+			archive, err := New(io.Discard, format)
 			require.NoError(t, err)
-			archive := New(file)
 			t.Cleanup(func() {
 				require.NoError(t, archive.Close())
-				require.NoError(t, file.Close())
 			})
 			require.NoError(t, archive.Add(config.File{
 				Source:      empty.Name(),
@@ -35,4 +34,9 @@ func TestArchive(t *testing.T) {
 			}))
 		})
 	}
+
+	t.Run("7z", func(t *testing.T) {
+		_, err := New(io.Discard, "7z")
+		require.EqualError(t, err, "invalid archive format: 7z")
+	})
 }
